@@ -29,10 +29,13 @@ def can_write(func, *args, **kwargs):
 
     # anonymous cannot write
     if request.user.is_anonymous:
-        raise AccessControlError("Template VM: The user doesn't have enough rights.")
+        raise AccessControlError(
+            "Template VM: The user doesn't have enough rights."
+        )
 
     template_version_manager = next(
-        (arg for arg in args if isinstance(arg, UserTemplateVersionManager)), None
+        (arg for arg in args if isinstance(arg, UserTemplateVersionManager)),
+        None,
     )
 
     # user is set
@@ -44,4 +47,6 @@ def can_write(func, *args, **kwargs):
         if request.user.is_staff:
             return func(*args, **kwargs)
 
-    raise AccessControlError("Template VM: The user doesn't have enough rights.")
+    raise AccessControlError(
+        "Template VM: The user doesn't have enough rights."
+    )
