@@ -1,13 +1,24 @@
 """ Initialize permissions for core user registration app.
 """
 import logging
+from os.path import join
 
 from django.contrib.auth.models import Group, Permission
+from django.contrib.staticfiles import finders
 from django.core.exceptions import ObjectDoesNotExist
 from django_celery_beat.models import CrontabSchedule, PeriodicTask
 
 import core_main_app.permissions.rights as main_rights
 import core_user_registration_app.permissions.rights as registration_rights
+from core_main_app.commons import exceptions
+from core_main_app.components.xsl_transformation import (
+    api as xslt_transformation_api,
+)
+from core_main_app.components.xsl_transformation.models import (
+    XslTransformation,
+)
+from core_main_app.system import api as system_api
+from core_main_app.utils.file import read_file_content
 from core_user_registration_app.components.user_template_version_manager import (
     api as user_version_manager_api,
 )
@@ -15,25 +26,15 @@ from core_user_registration_app.settings import (
     REGISTRY_XSD_USER_FILENAME,
     REGISTRY_XSD_USER_FILEPATH,
 )
-from core_user_registration_app.system import api as registry_system_api
-from core_user_registration_app.tasks import delete_user_data_structure
-
-logger = logging.getLogger(__name__)
-
-from os.path import join
-
-from django.contrib.staticfiles import finders
-
 from core_user_registration_app.settings import (
     XSL_FOLDER_PATH,
     LIST_XSL_FILENAME,
     DETAIL_XSL_FILENAME,
 )
-from core_main_app.commons import exceptions
+from core_user_registration_app.system import api as registry_system_api
+from core_user_registration_app.tasks import delete_user_data_structure
 
-from core_main_app.components.xsl_transformation import api as xslt_transformation_api
-from core_main_app.components.xsl_transformation.models import XslTransformation
-from core_main_app.utils.file import read_file_content
+logger = logging.getLogger(__name__)
 
 
 def init_registration_app():
@@ -53,7 +54,9 @@ def init_registration_app():
         # Init the xslt
         _init_xslt()
     except Exception as e:
-        logger.error("Impossible to init the registration app: {0}".format(str(e)))
+        logger.error(
+            "Impossible to init the registration app: {0}".format(str(e))
+        )
 
 
 def _init_permissions():
@@ -61,7 +64,7 @@ def _init_permissions():
     try:
         # Get or Create the default group
         anonymous, created = Group.objects.get_or_create(
-            name=main_rights.anonymous_group
+            name=main_rights.ANONYMOUS_GROUP
         )
 
         # Get registration permissions
@@ -99,7 +102,9 @@ def _add_user_template():
             "Please configure the REGISTRY_XSD_USER_FILEPATH setting in your project."
         )
     try:
-        registry_system_api.get_active_global_version_manager_by_title(xsd_filename)
+        registry_system_api.get_active_global_version_manager_by_title(
+            xsd_filename
+        )
     except exceptions.DoesNotExist:
         default_xsd_path = finders.find(xsd_filepath)
         xsd_data = read_file_content(default_xsd_path)
@@ -162,7 +167,9 @@ def _get_or_create_xslt(filename):
         )
 
 
-def _bind_template_xslt(template_id, list_xslt, default_detail_xslt, list_detail_xslt):
+def _bind_template_xslt(
+    template_id, list_xslt, default_detail_xslt, list_detail_xslt
+):
     """Bind the registry template with the XSLTs.
 
     Args:
@@ -182,13 +189,15 @@ def _bind_template_xslt(template_id, list_xslt, default_detail_xslt, list_detail
         template_xsl_rendering_api.get_by_template_id(template_id)
     except exceptions.DoesNotExist:
         template_xsl_rendering_api.add_or_delete(
-            template_id=template_id,
+            template=system_api.get_template_by_id(template_id),
             list_xslt=list_xslt,
             default_detail_xslt=default_detail_xslt,
             list_detail_xslt=list_detail_xslt,
         )
     except Exception as e:
-        raise Exception("Impossible to bind the template with XSLTs : " + str(e))
+        raise Exception(
+            "Impossible to bind the template with XSLTs : " + str(e)
+        )
 
 
 def _init_periodic_tasks():
