@@ -8,7 +8,6 @@ from django.http.response import HttpResponseBadRequest, HttpResponse
 
 from core_main_app.access_control.exceptions import AccessControlError
 from core_main_app.commons.exceptions import DoesNotExist
-from core_main_app.components.workspace import api as workspace_api
 from core_main_app.utils.xml import validate_xml_data
 from core_parser_app.components.data_structure_element import (
     api as data_structure_element_api,
@@ -21,7 +20,9 @@ from core_user_registration_app.components.user_data_structure import (
     api as user_data_structure_api,
 )
 from core_user_registration_app.components.user_metadata import api as data_api
-from core_user_registration_app.components.user_metadata.models import UserMetadata
+from core_user_registration_app.components.user_metadata.models import (
+    UserMetadata,
+)
 from xml_utils.xsd_tree.xsd_tree import XSDTree
 
 
@@ -32,10 +33,14 @@ def save_data(request):
         # get user data structure
         user_data_structure_id = request.POST["id"]
         account_request_metadata_id = request.POST["metadata"]
-        user_data_structure = user_data_structure_api.get_by_id(user_data_structure_id)
+        user_data_structure = user_data_structure_api.get_by_id(
+            user_data_structure_id
+        )
 
         # generate xml data
-        xml_data = render_xml(user_data_structure.data_structure_element_root, request)
+        xml_data = render_xml(
+            user_data_structure.data_structure_element_root, request
+        )
 
         # update user data structure data
         user_data_structure.form_string = xml_data
@@ -58,19 +63,17 @@ def save_data(request):
                 user_data_structure.data_structure_element_root, request
             )
 
-            if user_data_structure._data is not None:
-                # create new data
-                data = UserMetadata()
-                data.title = user_data_structure.name
-                data.template = user_data_structure.template
-                data.user_id = str(request.user.id)
-                data.id = user_data_structure.pk
-                data.workspace = workspace_api.get_global_workspace()
+            # create new data
+            data = UserMetadata()
+            data.title = user_data_structure.name
+            data.template = user_data_structure.template
+            data.user_id = str(request.user.id)
+            data.id = user_data_structure.pk
 
             # set content
             data.xml_content = xml_data
             # save data
-            data = data_api.upsert(data, request.user)
+            data_api.upsert(data, request.user)
             # insert Metadata reference in account request
             account_request_metadata_api.insert_metadata(
                 request.user, account_request_metadata_id, data
@@ -81,10 +84,13 @@ def save_data(request):
             )
     except Exception as e:
         message = str(e).replace('"', "'")
-        return HttpResponseBadRequest(message, content_type="application/javascript")
+        return HttpResponseBadRequest(
+            message, content_type="application/javascript"
+        )
 
     return HttpResponse(
-        json.dumps({"data_id": str(data.id)}), content_type="application/javascript"
+        json.dumps({"data_id": str(data.id)}),
+        content_type="application/javascript",
     )
 
 
@@ -134,7 +140,9 @@ def get_data_structure_element_value(request):
         return HttpResponseBadRequest()
 
     try:
-        element = data_structure_element_api.get_by_id(request.GET["id"], request)
+        element = data_structure_element_api.get_by_id(
+            request.GET["id"], request
+        )
         element_value = element.value
 
         if element.tag == "module":
@@ -144,7 +152,8 @@ def get_data_structure_element_value(request):
             }
 
         return HttpResponse(
-            json.dumps({"value": element_value}), content_type="application/json"
+            json.dumps({"value": element_value}),
+            content_type="application/json",
         )
     except (AccessControlError, DoesNotExist) as exc:
         return HttpResponseBadRequest(json.dumps({"message": str(exc)}))
