@@ -2,7 +2,7 @@
 """
 from unittest.case import TestCase
 
-from mock import patch
+from unittest.mock import patch
 
 import core_user_registration_app.components.user_data_structure.api as user_data_structure_api
 from core_main_app.commons import exceptions
@@ -26,14 +26,16 @@ class TestUserDataStructureGetById(TestCase):
         with self.assertRaises(exceptions.DoesNotExist):
             user_data_structure_api.get_by_id(1)
 
-    def test_data_structure_get_by_id_raises_model_error_if_not_found(self):
+    def test_data_structure_get_by_id_raises_doesnotexist_if_not_found(self):
 
         # Act # Assert
-        with self.assertRaises(exceptions.ModelError):
+        with self.assertRaises(exceptions.DoesNotExist):
             user_data_structure_api.get_by_id(1)
 
     @patch.object(UserDataStructure, "get_by_id")
-    def test_user_data_structure_get_by_id_return_data_if_found(self, mock_get):
+    def test_user_data_structure_get_by_id_return_data_if_found(
+        self, mock_get
+    ):
         # Arrange
         mock_data_structure = UserDataStructure(
             user="1", template=Template(), name="name"
@@ -47,7 +49,9 @@ class TestUserDataStructureGetById(TestCase):
 
 class TestUserDataStructureUpsert(TestCase):
     @patch.object(UserDataStructure, "save_object")
-    def test_user_data_structure_upsert_return_data_structure_element(self, mock_save):
+    def test_user_data_structure_upsert_return_data_structure_element(
+        self, mock_save
+    ):
         # Arrange
         mock_data_structure = UserDataStructure(
             user="1", template=Template(), name="name"
@@ -76,7 +80,9 @@ class TestUserDataStructureGetAll(TestCase):
             create_mock_user("1", is_staff=True, is_superuser=True)
         )
         # Assert
-        self.assertTrue(all(isinstance(item, UserDataStructure) for item in result))
+        self.assertTrue(
+            all(isinstance(item, UserDataStructure) for item in result)
+        )
 
 
 def _get_template():
